@@ -3,10 +3,7 @@ def load(h):
              'code': 0,
              'title': 'Seconds prior to initial reference time (defined in Section 1)',
              'units': 's'},
-            {'abbr': 1,
-             'code': 1,
-             'title': 'Meridional overturning stream function',
-             'units': 'm3/s'},
-            {'abbr': 2, 'code': 2, 'title': 'Reserved'},
+            {'abbr': 1, 'code': 1, 'title': 'Geographical latitude', 'units': 'deg N'},
+            {'abbr': 2, 'code': 2, 'title': 'Geographical longitude', 'units': 'deg E'},
             {'abbr': 3, 'code': 3, 'title': 'Days since last observation', 'units': 'd'},
             {'abbr': None, 'code': 255, 'title': 'Missing'})
